/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util;

/**
 * A utility class used by <CODE>International</CODE> that stores a country code and name pair.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 * @see International
 */
public final class Country
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String code;     // the country code
  private String name;     // the country name

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>Country</CODE> object.
   *
   * @param code The country code.
   * @param name The country name.
   */
  Country(String code, String name)
  {
    this.code = code.trim().toUpperCase();
    this.name = name.trim();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External getters
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns the 2-letter country code for this country.
   *
   * @return The 2-letter country code for this country.
   */
  public final String getCode()
  {
    return code;

  } // end code

  /**
   * Returns the name of this country.
   *
   * @return The name of this country.
   */
  public final String getName()
  {
    return name;

  } // end name

} // end class Country
