/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util.cache;

/**
 * An interface which allows external code to define a "strategy" for use with the <CODE>CacheMap</CODE>
 * object, in deciding which entries in the map are to be released.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 * @see CacheMap
 */
public interface CacheMapStrategy
{
  /**
   * Computes a "figure of merit" for a given <CODE>CacheMapEntry</CODE>. This value is used by the
   * <CODE>CacheMap</CODE> to determine which entries to remove; entries with lower "figure of merit"
   * values get removed first.
   *
   * @param entry The cache map entry to compute a figure of merit for.
   * @param tick The current time stamp, which may be used in a call to <CODE>CacheMapEntry.getAge</CODE>.
   * @return The "figure of merit" value.
   */
  public abstract long getEntryValue(CacheMapEntry entry, long tick);

} // end interface CacheMapStrategy
