/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util.cache;

/**
 * An exception thrown by the <CODE>ObjectCache</CODE> in unusual circumstances.  The main reason why this
 * exception would be thrown is if some code tried to register an object that was already in the cache.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 * @see ObjectCache#register(java.lang.Object,java.lang.Object)
 */
public class ObjectCacheException extends RuntimeException
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private Object keyval;   // key value

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new <CODE>ObjectCacheException</CODE>.
   *
   * @param msg The message to include with this exception.
   * @param keyval The key value of the object that caused this exception to be generated.
   */
  public ObjectCacheException(String msg, Object keyval)
  {
    super("[keyval " + keyval.toString() + "]: " + msg);
    this.keyval = keyval;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns the key value of the object that caused this exception to be generated.
   *
   * @return The key value of the object that caused this exception to be generated.
   */
  public Object getKeyVal()
  {
    return keyval;

  } // end getKeyVal

} // end class ObjectClassException
