/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.util.image;

import java.io.InputStream;

/**
 * A class used to return both an image's length in bytes and an <CODE>InputStream</CODE> containing
 * its data.
 *
 * @author Eric J. Bowersox &lt;erbo@silcom.com&gt;
 * @version X
 * @see ImageNormalizer
 */
public final class ImageLengthPair
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private int length;              // image length
  private InputStream data;        // image data

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  /**
   * Constructs a new object; usually called upon return from the <CODE>ImageNormalizer</CODE>.
   *
   * @param length Image length to be returned.
   * @param data Image data to be returned.
   * @see java.io.InputStream
   */
  public ImageLengthPair(int length, InputStream data)
  {
    this.length = length;
    this.data = data;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  /**
   * Returns the length of the image data.
   *
   * @return See above.
   */
  public final int getLength()
  {
    return length;

  } // end getLength

  /**
   * Returns the iage data expressed as an <CODE>InputStream</CODE>.
   *
   * @return See above.
   * @see java.io.InputStream
   */
  public final InputStream getData()
  {
    return data;

  } // end getData

} // end class ImageLengthPair
