/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core;

import java.util.Date;
import java.util.List;
import com.silverwrist.venice.htmlcheck.HTMLChecker;

public interface ConferenceContext
{
  public static final int GET_ALL = 0;
  public static final int DISPLAY_NEW = 1;
  public static final int DISPLAY_ACTIVE = 2;
  public static final int DISPLAY_ALL = 3;
  public static final int DISPLAY_HIDDEN = 4;
  public static final int DISPLAY_ARCHIVED = 5;

  public static final int SORT_TOPICID = 0;
  public static final int SORT_NUMBER = 1;
  public static final int SORT_NAME = 2;
  public static final int SORT_UNREAD = 3;
  public static final int SORT_TOTAL = 4;
  public static final int SORT_DATE = 5;

  public abstract int getConfID();

  public abstract String getName();
 
  public abstract String getDescription();

  public abstract Date getCreationDate();

  public abstract Date getLastUpdateDate();

  public abstract List getAliases() throws DataException;
  
  public abstract List getHosts() throws DataException;
  
  public abstract boolean canReadConference();

  public abstract boolean canPostToConference();

  public abstract boolean canCreateTopic();

  public abstract boolean canChangeConference();

  public abstract int getReadLevel() throws DataException, AccessError;

  public abstract int getPostLevel() throws DataException, AccessError;

  public abstract int getCreateLevel() throws DataException, AccessError;

  public abstract int getHideLevel() throws DataException, AccessError;

  public abstract int getNukeLevel() throws DataException, AccessError;

  public abstract int getChangeLevel() throws DataException, AccessError;

  public abstract int getDeleteLevel() throws DataException, AccessError;

  public abstract void setSecurityLevels(int read, int post, int create, int hide, int nuke,
					 int change, int delete) throws DataException, AccessError;

  public abstract void setName(String val) throws DataException, AccessError;

  public abstract void setDescription(String val) throws DataException, AccessError;

  public abstract void addAlias(String alias) throws DataException, AccessError;

  public abstract void removeAlias(String alias) throws DataException, AccessError;

  public abstract void setMembership(int uid, int grant_level) throws DataException, AccessError;

  public abstract void addMember(int uid, boolean as_host) throws DataException, AccessError;

  public abstract void removeMember(int uid) throws DataException, AccessError;

  public abstract int getCommunityGrantedLevel() throws DataException, AccessError;

  public abstract void setCommunityGrantedLevel(int new_level) throws DataException, AccessError;

  public abstract short getSequence() throws DataException, AccessError;

  public abstract void setSequence(short seq) throws DataException, AccessError;

  public abstract boolean getHideList() throws DataException, AccessError;

  public abstract void setHideList(boolean flag) throws DataException, AccessError;

  public abstract boolean canSetHideList();

  public abstract String getDefaultPseud();

  public abstract void setDefaultPseud(String val) throws DataException;

  public abstract boolean anyUnread();

  public abstract List getTopicList(int get_option, int sort_option) throws DataException, AccessError;

  public abstract TopicContext getTopic(short number) throws DataException, AccessError;

  public abstract TopicContext addTopic(String title, String zp_pseud, String zp_text)
      throws DataException, AccessError;

  public abstract TopicMessageContext getMessageByPostID(long postid) throws DataException, AccessError;

  public abstract HTMLChecker getNewTopicPreviewChecker();

  public abstract void fixSeen() throws DataException, AccessError;

  public abstract List getActivePosters(int skip, int limit) throws DataException, AccessError;

  public abstract List getActivePosters(int limit) throws DataException, AccessError;

  public abstract List getActivePosters() throws DataException, AccessError;

  public abstract List getActiveReaders(int skip, int limit) throws DataException, AccessError;

  public abstract List getActiveReaders(int limit) throws DataException, AccessError;

  public abstract List getActiveReaders() throws DataException, AccessError;

  public abstract List getMemberList() throws DataException, AccessError;

  public abstract int getMemberLevel(int uid) throws DataException, AccessError;

  public abstract void delete() throws DataException, AccessError;

  public abstract boolean canDeleteConference();

  public abstract boolean isInHotlist();

  public abstract void addToHotlist() throws DataException;

  public abstract boolean canAddToHotlist();

  public abstract CommunityContext getEnclosingCommunity();

  public abstract void removeFromHotlist() throws DataException;

  public abstract void setHotlistSequence(int seq) throws DataException;

  public abstract boolean displayPostPictures();

  public abstract ConferenceProperties getProperties() throws DataException, AccessError;

  public abstract void setProperties(ConferenceProperties props) throws DataException, AccessError;

} // end interface ConferenceContext
