/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import java.sql.Connection;
import java.util.Date;
import java.util.List;
import com.silverwrist.venice.core.ConferenceProperties;
import com.silverwrist.venice.core.DataException;

public interface ConferenceData
{
  public abstract int getID();

  public abstract String getName();
 
  public abstract String getDescription();

  public abstract Date getCreationDate();

  public abstract Date getLastUpdateDate();

  public abstract List getAliases() throws DataException;

  public abstract List getHosts() throws DataException;
  
  public abstract boolean canReadConference(int level);

  public abstract boolean canPostToConference(int level);

  public abstract boolean canCreateTopic(int level);

  public abstract boolean canChangeConference(int level);

  public abstract int getReadLevel();

  public abstract int getPostLevel();

  public abstract int getCreateLevel();

  public abstract int getHideLevel();

  public abstract int getNukeLevel();

  public abstract int getChangeLevel();

  public abstract int getDeleteLevel();

  public abstract void setSecurityLevels(EnvCommunity outer, int read, int post, int create, int hide,
					 int nuke, int change, int delete) throws DataException;

  public abstract void setName(EnvCommunity outer, String val) throws DataException;

  public abstract void setDescription(String val) throws DataException;

  public abstract void addAlias(EnvCommunity outer, String alias) throws DataException;

  public abstract void removeAlias(EnvCommunity outer, String alias) throws DataException;

  public abstract void setMembership(EnvCommunity outer, int uid, int grant_level) throws DataException;

  public abstract boolean canHideTopics(int level);

  public abstract String getAnAlias() throws DataException;

  public abstract ReturnTopicInfo createNewTopic(EnvCommunity outer, String title, String pseud,
						 String body, int body_lines) throws DataException;

  public abstract boolean canScribblePosts(int level);

  public abstract boolean canNukePosts(int level);

  public abstract void touchUpdate(Connection conn, Date date) throws DataException;

  public abstract short enterCreateTopic();

  public abstract void exitCreateTopic();

  public abstract short getTopTopic();

  public abstract List getMemberList() throws DataException;

  public abstract int getMemberLevel(int uid) throws DataException;

  public abstract boolean isDeleted();

  public abstract boolean canDeleteConference(int level);

  public abstract void delete(EnvCommunity outer) throws DataException;

  public abstract boolean displayPostPictures();

  public abstract ConferenceProperties getProperties();

  public abstract void setProperties(ConferenceProperties props) throws DataException;

} // end interface ConferenceData
