/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import java.util.BitSet;
import java.util.List;
import com.silverwrist.venice.security.AuditRecord;
import com.silverwrist.venice.security.Role;
import com.silverwrist.venice.security.SecurityMonitor;
import com.silverwrist.venice.htmlcheck.HTMLChecker;
import com.silverwrist.venice.core.DataException;
import com.silverwrist.venice.core.GlobalProperties;
import com.silverwrist.venice.core.SideBoxDescriptor;
import com.silverwrist.venice.core.TopicMessageContext;
import com.silverwrist.venice.core.VeniceEngine;

public interface EngineBackend
{
  // HTML checker types
  public static final int HTMLC_POST_BODY = 0;
  public static final int HTMLC_POST_PSEUD = 1;
  public static final int HTMLC_PREVIEW_BODY = 2;
  public static final int HTMLC_ESCAPE_BODY_PSEUD = 3;

  // Integer parameter indexes
  public static final int IP_POSTSPERPAGE = 0;
  public static final int IP_POSTSATTOP = 1;
  public static final int IP_MAXSEARCHRETURN = 2;
  public static final int IP_MAXCOMMUNITYMEMBERDISPLAY = 3;
  public static final int IP_MAXCONFMEMBERDISPLAY = 4;
  public static final int IP_NUMFRONTPAGEPOSTS = 5;
  public static final int IP_NUMAUDITRECSPERPAGE = 6;
  public static final int IP_CREATECOMMUNITYLVL = 7;
  public static final int IPC_NUM_PARAMS = 8;

  // Boolean parameter indexes
  public static final int BP_POSTPICTURES = 0;

  // role parameter indexes
  public static final int ROLEP_CREATECOMMUNITY = 0;

  // Selectors for security monitors
  public static final int SM_GLOBAL = 0;
  public static final int SM_COMMUNITY = 1;

  public abstract VeniceEngine getSelf();

  public abstract Emailer createEmailer();

  public abstract String getStockMessage(String key);

  public abstract int getNewConfirmationNumber();

  public abstract CommunityData getCommunityDataObject(int cid) throws DataException;

  public abstract void detachCommunityDataObject(int cid);

  public abstract BitSet getLockedFeaturesMask();

  public abstract List getCommunityFeatureSet(BitSet enabled_features, int level, boolean read_privs);

  public abstract String getAppletForFeature(int code);

  public abstract boolean isValidInitialFeatureIndex(short ndx);

  public abstract BitSet getDefaultFeaturesMask();

  public abstract void registerNewCommunity(CommunityData comm);

  public abstract int getFeatureIndexBySymbol(String symbol);

  public abstract boolean canAccessFeature(String symbol, int level, boolean has_read);

  public abstract ConferenceData getConferenceDataObject(int confid) throws DataException;

  public abstract void detachConferenceDataObject(int confid);

  public abstract void saveAuditRecord(AuditRecord ar);

  public abstract void registerNewConference(ConferenceData conf);

  public abstract HTMLChecker createCheckerObject(int type);

  public abstract int getParamInt(int selector);

  public abstract boolean getParamBoolean(int selector);

  public abstract Role getParamRole(int selector);

  public abstract void forceParamReload() throws DataException;

  public abstract SideBoxDescriptor getMasterSideBoxDescriptor(int id);

  public abstract void startPublish();

  public abstract void publishNew(TopicMessageContext pubmsg);

  public abstract void unpublish(long postid);

  public abstract String generateRandomAuthString();

  public abstract boolean isValidRandomAuthString(String s);

  public abstract boolean isNoCompressMimeType(String type);

  public abstract GlobalProperties getProperties();

  public abstract void setProperties(GlobalProperties props) throws DataException;

  public abstract SecurityMonitor env_getSecurityMonitor(int selector);

} // end interface EngineBackend
