/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.List;
import com.silverwrist.venice.core.AccessError;
import com.silverwrist.venice.core.SecurityInfo;
import com.silverwrist.venice.db.*;
import com.silverwrist.venice.security.*;

public class EnvEngine
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private EngineBackend engine;       // the engine
  private DataPool datapool;          // the database pool

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public EnvEngine(EngineBackend engine, DataPool datapool)
  {
    this.engine = engine;
    this.datapool = datapool;

  } // end constructor

  protected EnvEngine(EnvEngine other)
  {
    this.engine = other.engine;
    this.datapool = other.datapool;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Internal operations
   *--------------------------------------------------------------------------------
   */

  protected SecurityMonitor getStaticMonitor()
  {
    return engine.env_getSecurityMonitor(EngineBackend.SM_GLOBAL);

  } // end getStaticMonitor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final EngineBackend getEngine()
  {
    return engine;

  } // end getEngine

  public final DataPool getDataPool()
  {
    return datapool;

  } // end getDataPool

  public final Connection getConnection() throws SQLException
  {
    return datapool.getConnection();

  } // end getConnection

  public final void releaseConnection(Connection c)
  {
    if (c!=null)
      datapool.releaseConnection(c);

  } // end releaseConnection

  public final boolean permissionDefined(String symbol, boolean no_follow)
  {
    return getStaticMonitor().permissionDefined(symbol,no_follow);

  } // end permissionDefined

  public final List getRoleList(String symbol)
  {
    return getStaticMonitor().getRoleList(symbol);

  } // end getRoleList

  public final Role getRole(String symbol)
  {
    return getStaticMonitor().getRole(symbol);

  } // end getRole

  public final Role getRoleForLevel(int level)
  {
    return getStaticMonitor().getRoleForLevel(level);

  } // end getRoleForLevel

  public final Role getDefaultRole(String symbol)
  {
    return getStaticMonitor().getDefaultRole(symbol);

  } // end getDefaultRole

  public final SecurityInfo getSecurityInfo()
  {
    return new SecurityInfoWrapper(getStaticMonitor());

  } // end getSecurityInfo

} // end class EnvEngine
