/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.htmlcheck;

public interface HTMLTagSets
{
  /**
   * Denotes all tags that affect &quot;inline&quot; formatting only, such as
   * &lt;EM&gt; and &lt;B&gt;.  These are usually allowed.
   */
  public static final int INLINE_FORMAT = 1;
  /**
   * Denotes the &quot;A&quot; tag.
   */
  public static final int ANCHOR = 2;
  /**
   * Denotes all tags that affect &quot;block-level&quot; formatting, such as
   * &lt;P&gt; and &lt;Hn&gt;.
   */
  public static final int BLOCK_FORMAT = 3;
  /**
   * Denotes all tags that cause &quot;active&quot; content to be included in the
   * HTML document, such as &lt;OBJECT&gt;, &lt;APPLET&gt;, and &lt;SCRIPT&gt;.
   * These are generally not allowed.
   */
  public static final int ACTIVE_CONTENT = 4;
  /**
   * Denotes the tags that create clickable image maps, such as &lt;AREA&gt; and
   * &lt;MAP&gt;.
   */
  public static final int IMAGE_MAPS = 5;
  /**
   * Denotes the tags that are used for document-level formatting and structure, such as
   * &lt;HTML&gt;, &lt;BODY&gt;, and &lt;TITLE&gt;.  These are generally not allowed.
   */
  public static final int DOC_FORMAT = 6;
  /**
   * Denotes the &lt;FONT&gt; tag.
   */
  public static final int FONT_FORMAT = 7;
  /**
   * Denotes all tags that are used in conjunction with forms, such as
   * &lt;FORM&gt;, &lt;INPUT&gt;, and &lt;SELECT&gt;.
   */
  public static final int FORMS = 8;
  /**
   * Denotes all tags that are used in conjunction with tables, such as
   * &lt;TABLE&gt;, &lt;TR&gt;, and &lt;TD&gt;.
   */
  public static final int TABLES = 9;
  /**
   * Denotes the &lt;DEL&gt; and &lt;INS&gt; tags, which are used for change markup.
   */
  public static final int CHANGE_MARKUP = 10;
  /**
   * Denotes all tags related to frames, such as &lt;FRAMESET&gt; and &lt;FRAME&gt;.
   * These are generally not allowed.
   */
  public static final int FRAMES = 11;
  /**
   * Denotes the &lt;IMG&gt; tag.
   */
  public static final int IMAGES = 12;
  /**
   * Denotes tags like &lt;PRE&gt;, which are used to preformat input text.
   */
  public static final int PREFORMAT = 13;
  /**
   * Denotes Netscape-specific inline formatting, such as the hated &lt;BLINK&gt;.
   */
  public static final int NSCP_INLINE_FORMAT = 14;
  /**
   * Denotes Netscape's layer tags, such as &lt;LAYER&gt; and &lt;ILAYER&gt;.  These are
   * generally not allowed.
   */
  public static final int NSCP_LAYERS = 15;
  /**
   * Denotes Netscape-specific form tags, like &lt;KEYGEN&gt;.  These are generally
   * not allowed.
   */
  public static final int NSCP_FORMS = 16;
  /**
   * Denotes Netscape-specific block formatting tags, like &lt;MULTICOL&gt;.  These are
   * generally not allowed.
   */
  public static final int NSCP_BLOCK_FORMAT = 17;
  /**
   * Denotes the Netscape &lt;SERVER&gt; tag, used for server-side execution.  This is
   * generally not allowed.
   */
  public static final int NSCP_SERVER = 18;
  /**
   * Denotes Microsoft-specific document formatting tags, such as &lt;BGSOUND&gt;.  These
   * are generally not allowed.
   */
  public static final int MSFT_DOC_FORMAT = 19;
  /**
   * Denotes Microsoft-specific inline formatting tags, such as &lt;COMMENT&gt;.  These
   * are generally not allowed.
   */
  public static final int MSFT_INLINE_FORMAT = 20;
  /**
   * Denotes Microsoft-specific block formatting tags, such as &lt;MARQUEE&gt;.  These
   * are generally not allowed.
   */
  public static final int MSFT_BLOCK_FORMAT = 21;
  /**
   * Denotes Microsoft-specific active-content tags, such as &lt;XML&gt;.  These
   * are generally not allowed.
   */
  public static final int MSFT_ACTIVE_CONTENT = 22;
  /**
   * Denotes constructs for server-side page use only, such as with Microsoft Active
   * Server Pages and Sun Java Server Pages.  These are generally not allowed.
   */
  public static final int SERVER_PAGE = 23;
  /**
   * Denotes tags used by the Sun Java Server and other Java-compatible servers for
   * including server-side components.  These are generally not allowed.
   */
  public static final int JAVA_SERVER = 24;

} // end interface HTMLTagSets
