/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.security;

public interface SecLevels
{
  /**
   * Indicates "no access" (not even to the global system administrator).  Used as the
   * "delete" level for the Administration Community, so it can't be accidentally deleted.
   */
  public static final int NO_ACCESS = 65500;
  /**
   * Indicates a user with unrestricted access to all objects, but no admin privilege.
   * (Above the "low bands" of all scopes, but below the "high bands" of any of them.)
   */
  public static final int UNRESTRICTED_USER = 32500;
  /**
   * Indicates a user that has not logged in ("Anonymous Honyak").  Can be used as a
   * permission level for communities and conferences to permit public reading and/or anonymous
   * posting.
   */
  public static final int GLOBAL_ANONYMOUS = 100;
  /**
   * Indicates a user that has been registered, but has not yet had their email address
   * verified.
   */
  public static final int GLOBAL_UNVERIFIED = 500;
  /**
   * Indicates a user that has registered and been verified.  Can be used as a permission
   * level for communities and conferences to permit reading and/or posting by nonmembers.
   */
  public static final int GLOBAL_NORMAL = 1000;
  /**
   * The security level of the global system administrator ("Administrator" account, sometimes
   * known as the "BOFH" (Bastard Operator From Hell) account).
   */
  public static final int GLOBAL_BOFH = 64999;
  /**
   * A security level for "assistant admin" accounts (sometimes known as "PFY" (Pimply-
   * Faced Youth) accounts).
   */
  public static final int GLOBAL_PFY = 64000;
  /**
   * A security level used to indicate any account with global admin privileges.  Used
   * to control access to the Administration community.
   */
  public static final int GLOBAL_ANYADMIN = 63000;
  /**
   * The security level assigned to members of a community within that community.
   */
  public static final int COMM_MEMBER = 6500;
  /**
   * The security level assigned to cohosts of a community within that community.
   */
  public static final int COMM_COHOST = 58000;
  /**
   * The security level assigned to hosts of a community within that community.
   */
  public static final int COMM_HOST = 58500;
  /**
   * A security level used to indicate any account with admin privileges over a specific community.
   */
  public static final int COMM_ANYADMIN = 57000;
  /**
   * The maximum level in the "high band" of the community scope; used to test if a user already has
   * maximum privs within the community (because of being an admin at global scope, perhaps).
   */
  public static final int COMM_MAXADMIN = 58999;
  /**
   * The security level assigned to members of a (private) conference within that conference.
   */
  public static final int CONFERENCE_MEMBER = 12500;
  /**
   * The security level assigned to hosts of a conference within that conference.
   */
  public static final int CONFERENCE_HOST = 52500;
  /**
   * A security level used to indicate any account with admin privileges over a specific
   * conference.
   */
  public static final int CONFERENCE_ANYADMIN = 51000;

} // end interface SecLevels
