/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class CommunityFrontEnd extends VeniceServlet
{
  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public String getServletInfo()
  {
    String rc = "CommunityFrontEnd servlet - Redirects to the \"default feature\" of a community\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  /*--------------------------------------------------------------------------------
   * Overrides from class VeniceServlet
   *--------------------------------------------------------------------------------
   */

  protected VeniceContent doVeniceGet(HttpServletRequest request, VeniceEngine engine,
				      UserContext user, RenderData rdat)
    throws ServletException, IOException, VeniceServletResult
  {
    // get the community alias name from the request path info
    String alias = request.getPathInfo().substring(1);

    try
    { // get the community's context from the alias name
      CommunityContext comm = user.getCommunityContext(alias);

      // get the default servlet from the community context
      String def_servlet = comm.getDefaultApplet();
      if (def_servlet==null)
      { // return the default servlet
	changeMenuTop(request);
	return new ErrorBox("Internal Error","unable to get community default servlet","top");

      } // end if

      // and go there
      throw new RedirectResult(def_servlet);

    } // end try
    catch (DataException de)
    { // set up to display an ErrorBox
      changeMenuTop(request);
      return new ErrorBox("Database Error","Database error finding community: " + de.getMessage(),"top");

    } // end catch

  } // end doVeniceGet

} // end class CommunityFrontEnd
