/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class ImageRetrieve extends VeniceServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Category logger = Category.getInstance(ImageRetrieve.class);

  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public String getServletInfo()
  {
    String rc = "ImageRetrieve servlet - Displays images from the database image store\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  /*--------------------------------------------------------------------------------
   * Overrides from class VeniceServlet
   *--------------------------------------------------------------------------------
   */

  protected VeniceContent doVeniceGet(HttpServletRequest request, VeniceEngine engine,
				      UserContext user, RenderData rdat)
    throws ServletException, IOException, VeniceServletResult
  {
    int imgid;   // image ID to retrieve.

    try
    { // parse the image ID
      imgid = Integer.parseInt(request.getPathInfo().substring(1));

    } // end try
    catch (NumberFormatException nfe)
    { // invalid image URL
      return new ErrorBox(null,"Invalid image URL.",null);

    } // end catch

    // the parameters of the response
    String type, filename;
    int length;
    InputStream data;

    try
    { // load the image from the database
      BinaryData image = engine.loadImage(imgid);

      type = image.getMIMEType();
      filename = image.getFilename();
      length = image.getLength();
      data = image.getData();

    } // end try
    catch (DataException de)
    { // unable to get the user name
      return new ErrorBox("Database Error","Database error retrieving image: " + de.getMessage(),null);

    } // end catch

    // now we want to send that data back to the user!
    throw new SendFileResult(type,filename,length,data);

  } // end doVeniceGet

} // end class ImageRetrieve
