/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class PasswordRecovery extends VeniceServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Category logger = Category.getInstance(PasswordRecovery.class);

  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public String getServletInfo()
  {
    String rc = "PasswordRecovery servlet - Chnages passwords for users that forgot them\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  /*--------------------------------------------------------------------------------
   * Overrides from class VeniceServlet
   *--------------------------------------------------------------------------------
   */

  protected VeniceContent doVeniceGet(HttpServletRequest request, VeniceEngine engine,
				      UserContext user, RenderData rdat)
      throws ServletException, IOException, VeniceServletResult
  {
    int uid, auth;
    try
    { // retrieve UID and authentication strings from URL
      String foo = request.getPathInfo().substring(1);
      int n = foo.indexOf('.');
      if (n<0)
	return new ErrorBox(null,"Invalid parameters to password recovery.","top");
      uid = Integer.parseInt(foo.substring(0,n));
      auth = Integer.parseInt(foo.substring(n+1));

    } // end try
    catch (NumberFormatException nfe)
    { // invalid parameters passed...
      return new ErrorBox(null,"Invalid parameters to password recovery.","top");

    } // end catch

    try
    { // complete the password change
      engine.completePasswordChange(uid,auth);

      // now return a "password changed" page
      changeMenuTop(request);
      setMyLocation(request,"top");  // lie so that we get the "Log In" link up top
      return new PasswordChanged();

    } // end try
    catch (DataException de)
    { // there was a database error changing your password
      return new ErrorBox("Database Error","Database error changing password: " + de.getMessage(),"top");

    } // end catch
    catch (AccessError ae)
    { // this indicates a problem with the request ID or authentication
      return new ErrorBox("Invalid Request",ae.getMessage(),"top");

    } // end catch
    catch (EmailException ee)
    { // error sending the confirmation email
      return new ErrorBox("E-mail Error","E-mail error sending update: " + ee.getMessage(),"top");

    } // end catch

  } // end doVeniceGet

} // end class PasswordRecovery
