/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.IOException;
import com.silverwrist.venice.servlets.format.RenderData;

public class RedirectResult extends ExecuteResult
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String[] absolute_prefixes = { "http://", "ftp://" };

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String target;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public RedirectResult(String target)
  {
    super();
    this.target = target;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class ExecuteResult
   *--------------------------------------------------------------------------------
   */

  public void execute(RenderData rdat) throws IOException
  {
    for (int i=0; i<absolute_prefixes.length; i++)
      if (target.startsWith(absolute_prefixes[i]))
      { // this is an absolute redirection...do it!
	rdat.redirectAbsolute(target);
	return;

      } // end if and for

    rdat.redirectTo(target);

  } // end doRedirect

} // end class RedirectResult
