/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.servlets.format.RenderConfig;
import com.silverwrist.venice.servlets.format.RenderData;

public class StyleSheet extends HttpServlet
{
  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public String getServletInfo()
  {
    String rc = "StyleSheet applet - Generates a Cascading Stylesheet for Venice's use\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  public void doGet(HttpServletRequest request, HttpServletResponse response)
      throws ServletException, IOException
  {
    ServletContext ctxt = getServletContext();
    RenderData rdat = RenderConfig.createRenderData(ctxt,request,response);
    String stylesheet = Variables.getStyleSheetData(ctxt,rdat);
    if (stylesheet!=null)
    { // send back the stylesheet
      response.setContentType("text/css");
      response.setContentLength(stylesheet.length());
      PrintWriter out = response.getWriter();
      out.write(stylesheet);
      out.flush();
      response.flushBuffer();

    } // end if
    else  // no stylesheet data
      response.sendError(HttpServletResponse.SC_NOT_FOUND,"stylesheets not enabled");

  } // end doGet

} // end class StyleSheet
