/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.*;
import org.apache.log4j.xml.DOMConfigurator;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class Top extends VeniceServlet
{
  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public void init(ServletConfig config) throws ServletException
  {
    super.init(config);  // required before we do anything else
    ServletContext ctxt = config.getServletContext();
    String root_file_path = ctxt.getRealPath("/");
    if (!(root_file_path.endsWith("/")))
      root_file_path += "/";

    // Initialize LOG4J logging.
    String lconf = ctxt.getInitParameter("logging.config");
    if (!(lconf.startsWith("/")))
      lconf = root_file_path + lconf;
    DOMConfigurator.configure(lconf);

    // Initialize the Venice engine.
    VeniceEngine engine = Variables.getVeniceEngine(ctxt);

    // Initialize the Venice rendering system.
    RenderConfig.getRenderConfig(ctxt);

  } // end init

  public void destroy()
  {
    super.destroy();

  } // end destroy

  public String getServletInfo()
  {
    String rc = "Top applet - Displays the Venice front page\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  /*--------------------------------------------------------------------------------
   * Overrides from class VeniceServlet
   *--------------------------------------------------------------------------------
   */

  protected VeniceContent doVeniceGet(HttpServletRequest request, VeniceEngine engine,
				      UserContext user, RenderData rdat)
    throws ServletException, IOException, VeniceServletResult
  {
    changeMenuTop(request);
    setMyLocation(request,"top");

    try
    { // attempt to get the user content
      return new TopDisplay(getServletContext(),engine,user);

    } // end try
    catch (DataException de)
    { // there was a database error, whoops!
      return new ErrorBox("Database Error","Error loading front page: " + de.getMessage(),null);

    } // end catch
    catch (AccessError ae)
    { // there was an access error, whoops!
      return new ErrorBox("Access Error",ae.getMessage(),null);

    } // end catch

  } // end doVeniceGet

} // end class Top
