/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ValidationException;

public class CDCheckBoxFormField extends CDBaseFormFieldReverse
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static final String YES = "Y";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String on_value;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public CDCheckBoxFormField(String name, String caption, String caption2, String on_value)
  {
    super(name,caption,caption2,false);
    this.on_value = on_value;

  } // end constructor

  public CDCheckBoxFormField(String name, String caption, String caption2)
  {
    super(name,caption,caption2,false);
    this.on_value = YES;

  } // end constructor

  protected CDCheckBoxFormField(CDCheckBoxFormField other)
  {
    super(other);
    this.on_value = other.on_value;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class CDBaseFormFieldReverse
   *--------------------------------------------------------------------------------
   */

  protected void renderActualField(Writer out, RenderData rdat) throws IOException
  {
    out.write("<INPUT TYPE=CHECKBOX NAME=\"" + getName() + "\" VALUE=\"" + on_value + "\"");
    if (!isEnabled())
      out.write(" DISABLED");
    if (on_value.equals(getValue()))
      out.write(" CHECKED");
    out.write(">");

  } // end renderActualField

  /*--------------------------------------------------------------------------------
   * Implementations from interface CDFormField
   *--------------------------------------------------------------------------------
   */

  public Object getObjValue()
  {
    return new Boolean(on_value.equals(getValue()));

  } // end getObjValue

  public void setObjValue(Object obj)
  {
    if (obj instanceof Boolean)
      super.setValue(((Boolean)obj).booleanValue() ? on_value : "");
    else
      super.setObjValue(obj);

  } // end setObjValue

  public CDFormField duplicate()
  {
    return new CDCheckBoxFormField(this);

  } // end clone

} // end class CDCheckBoxFormField
