/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import java.io.Writer;
import java.io.IOException;
import com.silverwrist.util.StringUtil;

public class CDLocaleListFormField extends CDPickListFormField
{
  /*--------------------------------------------------------------------------------
   * Private list implementation
   *--------------------------------------------------------------------------------
   */

  static class LocaleList extends AbstractList
  {
    private Locale[] array;  // local array

    LocaleList()
    {
      array = Locale.getAvailableLocales();

    } // end constructor

    protected void finalize() throws Throwable
    {
      array = null;
      super.finalize();

    } // end finalize

    public Object get(int index)
    {
      return array[index];

    } // end get

    public int size()
    {
      return array.length;
      
    } // end size

  } // end class LocaleList

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public CDLocaleListFormField(String name, String caption, String caption2, boolean required)
  {
    super(name,caption,caption2,required,new LocaleList());

  } // end constructor

  protected CDLocaleListFormField(CDLocaleListFormField other)
  {
    super(other);

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Overrides from class CDPickListFormField
   *--------------------------------------------------------------------------------
   */

  protected void renderChoice(Writer out, RenderData rdat, Object obj, String my_value) throws IOException
  {
    Locale l = (Locale)obj;
    out.write("<OPTION VALUE=\"" + l.toString() + "\"");
    if (l.toString().equals(my_value))
      out.write(" SELECTED");
    out.write(">" + StringUtil.encodeHTML(l.getDisplayName()) + "</OPTION>\n");

  } // end renderChoice

  /*--------------------------------------------------------------------------------
   * Implementations from interface CDFormField
   *--------------------------------------------------------------------------------
   */

  public CDFormField duplicate()
  {
    return new CDLocaleListFormField(this);

  } // end duplicate

} // end class CDLocaleListFormField
