/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import javax.servlet.ServletRequest;

public class CDPasswordFormFieldCommand extends CDPasswordFormField
{
  private CDCommandButton button;

  public CDPasswordFormFieldCommand(String name, String caption, String caption2, boolean required,
				    int size, int maxlength, CDCommandButton button)
  {
    super(name,caption,caption2,required,size,maxlength);
    this.button = button;

  } // end constructor

  protected CDPasswordFormFieldCommand(CDPasswordFormFieldCommand other)
  {
    super(other);
    this.button = other.button;

  } // end constructor

  protected void renderActualField(Writer out, RenderData rdat) throws IOException
  {
    super.renderActualField(out,rdat);
    if (button!=null)
    { // add the button
      out.write("&nbsp;&nbsp;");
      button.renderHere(out,rdat);

    } // end if

  } // end renderActualField

  public CDCommandButton findButton(String name)
  {
    if ((button!=null) && (button.getName().equals(name)))
      return button;
    else
      return super.findButton(name);

  } // end findButton

  public CDFormField duplicate()
  {
    return new CDPasswordFormFieldCommand(this);

  } // end clone

} // end class CDPasswordFormFieldCommand
