/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.Iterator;
import java.util.List;
import java.io.Writer;
import java.io.IOException;
import com.silverwrist.util.StringUtil;

public abstract class CDPickListFormField extends CDBaseFormField
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private List choices;

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  protected CDPickListFormField(String name, String caption, String caption2, boolean required,
				List choices)
  {
    super(name,caption,caption2,required);
    this.choices = choices;

  } // end constructor

  protected CDPickListFormField(CDPickListFormField other)
  {
    super(other);
    this.choices = other.choices;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Abstract method declarations
   *--------------------------------------------------------------------------------
   */

  protected abstract void renderChoice(Writer out, RenderData rdat, Object obj, String my_value)
      throws IOException;

  /*--------------------------------------------------------------------------------
   * Overrides from class CDBaseFormField
   *--------------------------------------------------------------------------------
   */

  protected void renderActualField(Writer out, RenderData rdat) throws IOException
  {
    out.write("<SELECT CLASS=\"content\" NAME=\"" + getName() + "\" SIZE=1");
    if (!isEnabled())
      out.write(" DISABLED");
    out.write(">\n");
    Iterator it = choices.iterator();
    while (it.hasNext())
    { // render each of the choices in turn
      Object c = it.next();
      renderChoice(out,rdat,c,getValue());

    } // end while

    out.write("</SELECT>\n");  // all done

  } // end renderActualField

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public List getChoicesList()
  {
    return choices;

  } // end getChoicesList

  public void setChoicesList(List list)
  {
    this.choices = list;

  } // end setChoicesList

} // end class CDPickListFormField
