/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.ServletRequest;
import com.silverwrist.venice.core.*;

public class CommunityCategoryBrowseData implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.CommunityCategoryBrowseData";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String name;
  private String base_applet;
  private CategoryDescriptor prev_cat;
  private CategoryDescriptor curr_cat;
  private List subcats;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public CommunityCategoryBrowseData(UserContext user, CommunityContext comm, int current_id)
      throws DataException
  {
    name = comm.getName();
    base_applet = "sigadmin?sig=" + String.valueOf(comm.getCommunityID());
    prev_cat = comm.getCategory();
    if (prev_cat.getCategoryID()==current_id)
      curr_cat = prev_cat;
    else
      curr_cat = user.getCategoryDescriptor(current_id);
    subcats = curr_cat.getSubCategories();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static CommunityCategoryBrowseData retrieve(ServletRequest request)
  {
    return (CommunityCategoryBrowseData)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Set Community Category";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "commcatbrowser.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String getCommunityName()
  {
    return name;

  } // end if

  public String getCancelURL(RenderData rdat)
  {
    return rdat.getEncodedServletPath(base_applet);

  } // end getCancelURL

  public String getPreviousCategory()
  {
    return prev_cat.toString();

  } // end getPreviousCategory

  public CategoryDescriptor getCurrentCategory()
  {
    return curr_cat;

  } // end getCurrentCategory

  public String getGoLink(RenderData rdat, int catid)
  {
    return rdat.getEncodedServletPath(base_applet + "&cmd=T&go=" + String.valueOf(catid));

  } // end getGoLink

  public String getSetLink(RenderData rdat, int catid)
  {
    return rdat.getEncodedServletPath(base_applet + "&cmd=T&set=" + String.valueOf(catid));

  } // end getGoLink

  public Iterator getSubcategoryIterator()
  {
    return subcats.iterator();

  } // end getSubcategoryIterator

  public boolean hasSubcategories()
  {
    return (subcats.size()>0);

  } // end hasSubcategories

} // end class CommunityCategoryBrowseData
