/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import javax.servlet.ServletRequest;
import com.silverwrist.util.*;
import com.silverwrist.venice.core.*;

public class CommunityProfileData implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.CommunityProfileData";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private VeniceEngine engine;        // the Venice engine
  private UserContext user;           // the current user managing this
  private CommunityContext comm;      // the community being displayed
  private ContactInfo ci;             // community's contact info
  private UserProfile host_prof;      // community host's user profile
  private CategoryDescriptor cat;     // community's full category descriptor

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public CommunityProfileData(VeniceEngine engine, UserContext user, CommunityContext ctxt)
      throws DataException
  {
    this.engine = engine;
    this.user = user;
    this.comm = ctxt;
    this.ci = ctxt.getContactInfo();
    this.host_prof = ctxt.getHostProfile();
    this.cat = ctxt.getCategory();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static CommunityProfileData retrieve(ServletRequest request)
  {
    return (CommunityProfileData)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Community Profile: " + comm.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return "go/" + comm.getAlias() + "!";

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "commprofile.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public CommunityContext getCommunityContext()
  {
    return comm;

  } // end getCommunityContext

  public String getCommunityLogoURL(RenderData rdat)
  {
    String tmp = ci.getPhotoURL();
    if (StringUtil.isStringEmpty(tmp))
      tmp = rdat.getFullImagePath("sig_other.jpg");
    return tmp;

  } // end getCommunityLogoURL

  public boolean isUserLoggedIn()
  {
    return user.isLoggedIn();

  } // end isUserLoggedIn

  public String getHostUserName()
  {
    return host_prof.getUserName();

  } // end getHostUserName

  public ContactInfo getCommunityContactInfo()
  {
    return ci;

  } // end getCommunityContactInfo

  public String getAddressLastLine()
  {
    String tmp_c = ci.getLocality();
    String tmp_s = ci.getRegion();
    StringBuffer buf = new StringBuffer();
    if (!(StringUtil.isStringEmpty(tmp_c)) && !(StringUtil.isStringEmpty(tmp_s)))
      buf.append(tmp_c).append(", ").append(tmp_s);
    else if (!(StringUtil.isStringEmpty(tmp_c)))
      buf.append(tmp_c);
    else if (!(StringUtil.isStringEmpty(tmp_s)))
      buf.append(tmp_s);
    tmp_s = ci.getPostalCode();
    if (!(StringUtil.isStringEmpty(tmp_s)))
      buf.append(' ').append(tmp_s);
    return buf.toString();

  } // end getAddressLastLine

  public String getFullCountry()
  {
    Country c = International.get().getCountryForCode(ci.getCountry());
    return ((c==null) ? null : c.getName());

  } // end getFullCountry

  public CategoryDescriptor getCategory()
  {
    return cat;

  } // end getCategory

} // end class CommunityProfileData
