/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class ConferenceActivity implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ConferenceActivity";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;        // the community we're in
  private ConferenceContext conf;       // the conference being listed
  private TopicContext topic;           // the topic being listed
  private boolean posters;              // is this a list of posters?
  private List records;                 // the actual data records
  private String locator = null;        // our locator

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceActivity(CommunityContext comm, ConferenceContext conf, TopicContext topic, boolean posters)
      throws DataException, AccessError
  {
    this.comm = comm;
    this.conf = conf;
    this.topic = topic;
    this.posters = posters;
    if (topic!=null)
    { // do the report on the topic
      if (posters)
	this.records = topic.getActivePosters();
      else
	this.records = topic.getActiveReaders();

    } // end if
    else
    { // do the report on the conference
      if (posters)
	this.records = conf.getActivePosters();
      else
	this.records = conf.getActiveReaders();

    } // end else

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ConferenceActivity retrieve(ServletRequest request)
  {
    return (ConferenceActivity)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    if (topic!=null)
    { // it's a topic report
      if (posters)
	return "Users Posting in Topic " + topic.getName();
      else
	return "Users Reading Topic " + topic.getName();

    } // end if
    else
    { // it's a conference report
      if (posters)
	return "Users Posting in Conference " + conf.getName();
      else
	return "Users Reading Conference " + conf.getName();

    } // end else

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "conf_activity.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String getConfName()
  {
    return conf.getName();

  } // end getConfName

  public String getTopicName()
  {
    if (topic==null)
      return null;
    else
      return topic.getName();

  } // end getTopicName

  public String getLocator()
  {
    if (locator==null)
      locator = "sig=" + comm.getCommunityID() + "&conf=" + conf.getConfID();
    return locator;

  } // end getLocator

  public boolean isTopicReport()
  {
    return (topic!=null);

  } // end isTopicReport

  public boolean isPosterReport()
  {
    return posters;

  } // end isPosterReport

  public boolean anyElements()
  {
    return (records.size()>0);

  } // end anyElements

  public Iterator getRecordsIterator()
  {
    return records.iterator();

  } // end getRecordsIterator

} // end class ConferenceActivity
