/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.ServletRequest;
import com.silverwrist.venice.core.*;

public class ConferenceListing implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ConferenceListing";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;
  private List conferences;
  private List[] hosts;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceListing(CommunityContext comm) throws DataException, AccessError
  {
    this.comm = comm;
    this.conferences = comm.getConferences();
    this.hosts = new List[this.conferences.size()];
    for (int i=0; i<this.conferences.size(); i++)
      this.hosts[i] = ((ConferenceContext)(this.conferences.get(i))).getHosts();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ConferenceListing retrieve(ServletRequest request)
  {
    return (ConferenceListing)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Conference Listing: " + comm.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return "go/" + comm.getAlias() + "!";

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "conferences.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public String getCommunityName()
  {
    return comm.getName();

  } // end getCommunityName

  public int getNumConferences()
  {
    return conferences.size();

  } // end getNumConferences

  public int getConferenceID(int ndx)
  {
    return ((ConferenceContext)(conferences.get(ndx))).getConfID();

  } // end getConferenceID

  public String getConferenceName(int ndx)
  {
    return ((ConferenceContext)(conferences.get(ndx))).getName();

  } // end getConferenceID

  public String getDescription(int ndx)
  {
    return ((ConferenceContext)(conferences.get(ndx))).getDescription();

  } // end getDescription

  public Date getLastUpdateDate(int ndx)
  {
    return ((ConferenceContext)(conferences.get(ndx))).getLastUpdateDate();

  } // end getLastUpdateDate

  public boolean anyUnread(int ndx)
  {
    return ((ConferenceContext)(conferences.get(ndx))).anyUnread();

  } // end anyUnread

  public int getNumHosts(int ndx)
  {
    return hosts[ndx].size();

  } // end getNumHosts

  public String getHostName(int ndx, int h)
  {
    return ((UserFound)(hosts[ndx].get(h))).getName();

  } // end getHostName

  public boolean canCreateConference()
  {
    return comm.canCreateConference();

  } // end canCreateConference

  public boolean canManageConferences()
  {
    return comm.canManageConferences();

  } // end canManageConferences

} // end class ConferenceListing
