/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class ConferenceSequence implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ConferenceSequence";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;
  private List conf_list;
  private Hashtable hidden_stat = new Hashtable();
  private Hashtable next_id = new Hashtable();
  private Hashtable prev_id = new Hashtable();

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceSequence(CommunityContext comm) throws DataException, AccessError
  {
    this.comm = comm;
    this.conf_list = comm.getConferences();

    Integer last_id = null;
    for (int i=0; i<conf_list.size(); i++)
    { // build up the "next_id" and "prev_id" mappings
      ConferenceContext conf = (ConferenceContext)(conf_list.get(i));
      Integer this_id = new Integer(conf.getConfID());

      // save conference "hidden" status
      hidden_stat.put(this_id,new Boolean(conf.getHideList()));

      if (last_id!=null)
      { // establish the "next" and "prev" IDs for the conferences
	next_id.put(last_id,this_id);
	prev_id.put(this_id,last_id);

      } // end if

      last_id = this_id;

    } // end for

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ConferenceSequence retrieve(ServletRequest request)
  {
    return (ConferenceSequence)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Manage Conference List";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "conf_sequence.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getNumConferences()
  {
    return conf_list.size();

  } // end getNumConferences

  public ConferenceContext getConference(int ndx)
  {
    return (ConferenceContext)(conf_list.get(ndx));

  } // end getConference

  public boolean isConferenceHidden(ConferenceContext conf)
  {
    Boolean value = (Boolean)(hidden_stat.get(new Integer(conf.getConfID())));
    if (value==null)
      return false;
    else
      return value.booleanValue();

  } // end isConferenceHidden

  public int getNextConfID(ConferenceContext conf)
  {
    Integer value = (Integer)(next_id.get(new Integer(conf.getConfID())));
    if (value==null)
      return 0;
    else
      return value.intValue();

  } // end getNextConfID

  public int getPrevConfID(ConferenceContext conf)
  {
    Integer value = (Integer)(prev_id.get(new Integer(conf.getConfID())));
    if (value==null)
      return 0;
    else
      return value.intValue();

  } // end getPrevConfID

} // end class ConferenceSequence
