/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class ManageConferenceAliases implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ManageConferenceAliases";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;        // the community we're in
  private ConferenceContext conf;       // the conference being listed
  private List aliases;                 // list of aliases generated
  private String error_message;         // error message to display

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public ManageConferenceAliases(CommunityContext comm, ConferenceContext conf) throws DataException
  {
    this.comm = comm;
    this.conf = conf;
    this.aliases = conf.getAliases();
    this.error_message = null;

  } // end constructor

  public ManageConferenceAliases(CommunityContext comm, ConferenceContext conf, String message)
      throws DataException
  {
    this.comm = comm;
    this.conf = conf;
    this.aliases = conf.getAliases();
    this.error_message = message;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ManageConferenceAliases retrieve(ServletRequest request)
  {
    return (ManageConferenceAliases)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Manage Conference Aliases: " + conf.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "manage_aliases.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getConfID()
  {
    return conf.getConfID();

  } // end getConfID

  public String getConfName()
  {
    return conf.getName();

  } // end getConfName

  public String getLocator()
  {
    return "sig=" + comm.getCommunityID() + "&conf=" + conf.getConfID();

  } // end getLocator

  public boolean canRemoveAliases()
  {
    return (aliases.size()>1);

  } // end canRemoveAliases

  public Iterator getAliasIterator()
  {
    return aliases.iterator();

  } // end getAliasIterator

  public String getErrorMessage()
  {
    return error_message;

  } // end getErrorMessage

} // end class ManageConferenceAliases
