/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class ManageTopic implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ManageTopic";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;        // the community we're in
  private ConferenceContext conf;       // the conference being listed
  private TopicContext topic;           // the topic being managed
  private String locator = null;        // the locator we use
  private List bozos_list;              // the list of "bozo" users

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ManageTopic(UserContext user, CommunityContext comm, ConferenceContext conf, TopicContext topic)
      throws DataException
  {
    this.comm = comm;
    this.conf = conf;
    this.topic = topic;

    // Load up the list of bozos, sorting them in user name order.
    List bozo_uids = topic.getBozos();
    if (bozo_uids.size()>0)
    { // use a TreeMap to do the sorting
      TreeMap load_map = new TreeMap();
      Iterator it = bozo_uids.iterator();
      while (it.hasNext())
      { // fill in the list of user profiles
	Integer uid = (Integer)(it.next());
	UserProfile prof = user.getProfile(uid.intValue());
	load_map.put(prof.getUserName(),prof);

      } // end while

      bozos_list = new ArrayList(load_map.values());

    } // end if
    else  // no bozos - just set empty list
      bozos_list = Collections.EMPTY_LIST;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ManageTopic retrieve(ServletRequest request)
  {
    return (ManageTopic)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Manage Topic: " + topic.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "manage_topic.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getConfID()
  {
    return conf.getConfID();

  } // end getConfID

  public int getTopicNumber()
  {
    return topic.getTopicNumber();

  } // end getTopicID

  public String getTopicName()
  {
    return topic.getName();

  } // end getConfName

  public String getLocator()
  {
    if (locator==null)
      locator = "sig=" + comm.getCommunityID() + "&conf=" + conf.getConfID() + "&top="
	               + topic.getTopicNumber();
    return locator;

  } // end getLocator

  public int getNumBozos()
  {
    return bozos_list.size();

  } // end getNumBozos()

  public Iterator getBozosIterator()
  {
    return bozos_list.iterator();

  } // end getBozosIterator

} // end class ManageTopic
