/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import javax.servlet.ServletRequest;
import com.silverwrist.venice.core.CommunityContext;

public class NewCommunityWelcome implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.NewCommunityWelcome";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String name;
  private String entry_url;
  private String invite_url;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public NewCommunityWelcome(CommunityContext comm)
  {
    name = comm.getName();
    entry_url = "sig/" + comm.getAlias();
    invite_url = "sigops?cmd=I&sig=" + comm.getCommunityID();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static NewCommunityWelcome retrieve(ServletRequest request)
  {
    return (NewCommunityWelcome)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "New Community Created";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "newcommwelcome.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String getCommunityName()
  {
    return name;

  } // end getCommunityName

  public String getEntryURL(RenderData rdat)
  {
    return rdat.getEncodedServletPath(entry_url);

  } // end getEntryURL

  public String getDisplayURL(RenderData rdat)
  {
    return rdat.getCompleteServletPath(entry_url);

  } // end getEntryURL

  public String getInviteURL(RenderData rdat)
  {
    return rdat.getEncodedServletPath(invite_url);

  } // end getInviteURL

} // end class NewCommunityWelcome
