/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.htmlcheck.*;
import com.silverwrist.venice.core.*;

public class PostPreview implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.PostPreview";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;
  private ConferenceContext conf;
  private TopicContext topic;
  private String next;
  private String pseud;
  private String data;
  private String preview;
  private int num_errors;
  private int msgs;
  private boolean attach;
  private boolean slippage;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public PostPreview(VeniceEngine engine, CommunityContext comm, ConferenceContext conf, TopicContext topic,
                     String pseud, String data, String next, int msgs, boolean attach, boolean slippage)
  {
    this.comm = comm;
    this.conf = conf;
    this.topic = topic;
    this.next = next;
    this.msgs = msgs;
    this.attach = attach;
    this.slippage = slippage;

    try
    { // sanitize the pseud data
      HTMLChecker check = engine.getEscapingChecker();
      check.append(pseud);
      check.finish();
      this.pseud = check.getValue();

      // sanitize the post box data
      check.reset();
      check.append(data);
      check.finish();
      this.data = check.getValue();

      // now generate the preview
      check = topic.getPreviewChecker();
      check.append(data);
      check.finish();
      this.preview = check.getValue();
      this.num_errors = check.getCounter("spelling");

    } // end try
    catch (HTMLCheckerException e)
    { // this is a bad issue...
      throw new InternalStateError("spurious HTMLCheckerException thrown");

    } // end catch

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static PostPreview retrieve(ServletRequest request)
  {
    return (PostPreview)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Previewing Message";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "preview.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getNumSpellingErrors()
  {
    return num_errors;

  } // end getNumSpellingErrors

  public String getPreviewData()
  {
    return preview;

  } // end getPreviewData

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getConfID()
  {
    return conf.getConfID();

  } // end getConfID

  public int getTopicNumber()
  {
    return topic.getTopicNumber();

  } // end getTopicNumber

  public int getTotalMessages()
  {
    return msgs;

  } // end getTotalMessages

  public String getNextVal()
  {
    return next;

  } // end getNextVal

  public String getPseud()
  {
    return pseud;

  } // end getPseud

  public boolean attachChecked()
  {
    return attach;

  } // end attachChecked

  public String getBodyText()
  {
    return data;

  } // end getBodyText

  public boolean slippageDetected()
  {
    return slippage;

  } // end slippageDetected

} // end class PostPreview
