/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.htmlcheck.*;
import com.silverwrist.venice.core.*;

public class PostSlippage implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.PostSlippage";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;
  private ConferenceContext conf;
  private TopicContext topic;
  private List messages;
  private String next;
  private String pseud;
  private String text;
  private boolean attach;
  private String topic_stem;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public PostSlippage(VeniceEngine engine, CommunityContext comm, ConferenceContext conf, TopicContext topic,
                      int lastval, String next, String pseud, String text, boolean attach)
      throws DataException, AccessError
  {
    this.comm = comm;
    this.conf = conf;
    this.topic = topic;
    this.messages = topic.getMessages(lastval,topic.getTotalMessages()-1);
    this.next = next;
    this.attach = attach;
    List aliases = conf.getAliases();
    topic_stem = (String)(aliases.get(0)) + "." + String.valueOf(topic.getTopicNumber()) + ".";

    try
    { // run the text and pseud through an HTML checker to escape them
      HTMLChecker ch = engine.getEscapingChecker();
      ch.append(pseud);
      ch.finish();
      this.pseud = ch.getValue();
      ch.reset();
      ch.append(text);
      ch.finish();
      this.text = text;

    } // end try
    catch (HTMLCheckerException e)
    { // this shouldn't happen
      throw new InternalStateError("spurious HTMLCheckerException thrown");

    } // end catch

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static PostSlippage retrieve(ServletRequest request)
  {
    return (PostSlippage)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Slippage or Double-Click Detected";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "slippage.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public static String getPosterName(TopicMessageContext msg)
  {
    try
    { // have to guard agains a DataException here
      return msg.getCreatorName();

    } // end try
    catch (DataException de)
    { // just return "unknown" on failure
      return "(unknown)";

    } // end catch

  } // end getPosterName

  public static String getMessageBodyText(TopicMessageContext msg)
  {
    try
    { // have to guard against a DataException here
      return msg.getBodyText();

    } // end try
    catch (DataException de)
    { // just return an error message
      return "<EM>(Unable to retrieve message data: " + StringUtil.encodeHTML(de.getMessage()) + ")</EM>";

    } // end catch

  } // end getMessageBodyText

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getConfID()
  {
    return conf.getConfID();

  } // end getConfID

  public int getTopicNumber()
  {
    return topic.getTopicNumber();

  } // end getTopicNumber

  public String getTopicName()
  {
    return topic.getName();

  } // end getTopicName

  public String getIdentifyingData()
  {
    return "Slippage posting to topic " + String.valueOf(topic.getTopicID());

  } // end getIdentifyingData

  public int getTotalMessages()
  {
    return topic.getTotalMessages();

  } // end getTotalMessages

  public Iterator getMessageIterator()
  {
    return messages.iterator();

  } // end getMessageIterator

  public String getNextVal()
  {
    return next;

  } // end getNextVal

  public String getPseud()
  {
    return pseud;

  } // end getPseud

  public boolean attachChecked()
  {
    return attach;

  } // end attachChecked

  public String getBodyText()
  {
    return text;

  } // end getBodyText

  public String getMessageReference(TopicMessageContext msg)
  {
    return topic_stem + String.valueOf(msg.getPostNumber());

  } // end getMessageReference

} // end class PostSlippage
