/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class SideBoxList implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.SideBoxList";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private UserContext uc;           // user context
  private List in_list;             // sideboxes that are "in"
  private List out_list;            // sideboxes that are "out"

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public SideBoxList(VeniceEngine engine, UserContext uc) throws DataException
  {
    this.uc = uc;
    this.in_list = uc.getSideBoxList();
    HashSet ids = new HashSet(in_list.size());
    Iterator it = in_list.iterator();
    while (it.hasNext())
    { // add the IDs of all the sideboxes to the set
      SideBoxDescriptor d = (SideBoxDescriptor)(it.next());
      ids.add(new Integer(d.getID()));

    } // end while

    List all_list = engine.getMasterSideBoxList();
    if (all_list.size()>in_list.size())
    { // allocate an ArrayList to hold the sideboxes
      out_list = new ArrayList(all_list.size()-in_list.size());
      it = all_list.iterator();
      while (it.hasNext())
      { // get all sideboxes not in the "in" list and put them in the "out" list
	SideBoxDescriptor d = (SideBoxDescriptor)(it.next());
	if (!(ids.contains(new Integer(d.getID()))))
	  out_list.add(d);

      } // end while

    } // end if
    else  // all sideboxes are "in"...
      out_list = Collections.EMPTY_LIST;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static SideBoxList retrieve(ServletRequest request)
  {
    return (SideBoxList)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Your Front Page Configuration";

  } // end getPageTitle

  public String getPageQID()
  {
    return null;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "sideboxlist.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getInListSize()
  {
    return in_list.size();

  } // end getInListSize

  public SideBoxDescriptor getInListItem(int index)
  {
    return (SideBoxDescriptor)(in_list.get(index));

  } // end getInListItem

  public int getOutListSize()
  {
    return out_list.size();

  } // end getOutListSize

  public SideBoxDescriptor getOutListItem(int index)
  {
    return (SideBoxDescriptor)(out_list.get(index));

  } // end getInListItem

} // end class SideBoxList

