/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class TopicListing implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.TopicListing";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private CommunityContext comm;        // the community we're in
  private ConferenceContext conf;       // the conference being listed
  private int view_opt;                 // the view option used
  private int sort_opt;                 // the sort option used
  private List topic_list;              // the topic list
  private TopicVisitOrder visit_order;  // indicates order in which topics are visited
  private String qid;                   // "quick ID" for this page

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public TopicListing(HttpServletRequest request, CommunityContext comm, ConferenceContext conf, int view_opt,
		      int sort_opt) throws DataException, AccessError
  {
    this.comm = comm;
    this.conf = conf;
    this.view_opt = view_opt;
    this.sort_opt = sort_opt;
    this.topic_list = conf.getTopicList(view_opt,sort_opt);
    this.visit_order = TopicVisitOrder.initialize(request.getSession(true),conf.getConfID(),this.topic_list);
    List aliases = conf.getAliases();
    this.qid = "go/" + comm.getAlias() + "!" + (String)(aliases.get(0));

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static TopicListing retrieve(ServletRequest request)
  {
    return (TopicListing)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "Topics in " + conf.getName();

  } // end getPageTitle

  public String getPageQID()
  {
    return qid;

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "topics.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public int getCommunityID()
  {
    return comm.getCommunityID();

  } // end getCommunityID

  public int getConfID()
  {
    return conf.getConfID();

  } // end getConfID

  public String getLocator()
  {
    StringBuffer buf = new StringBuffer("sig=");
    buf.append(comm.getCommunityID()).append("&conf=").append(conf.getConfID());
    return buf.toString();

  } // end getLocator

  public String getConfName()
  {
    return conf.getName();

  } // end getConfName

  public boolean canDoReadNew()
  {
    return visit_order.isNext();

  } // end canDoReadNew

  public String getNextLocator()
  {
    StringBuffer buf = new StringBuffer("sig=");
    buf.append(comm.getCommunityID()).append("&conf=").append(conf.getConfID()).append("&top=");
    buf.append(visit_order.getNext());
    return buf.toString();

  } // end getNextLocator

  public boolean canCreateTopic()
  {
    return conf.canCreateTopic();

  } // end canCreateTopic

  public boolean canAddToHotlist()
  {
    return conf.canAddToHotlist();

  } // end canAddToHotlist

  public boolean anyTopics()
  {
    return (topic_list.size()>0);

  } // end anyTopics

  public int getViewOption()
  {
    return view_opt;

  } // end getViewOption

  public boolean isView(int value)
  {
    return (view_opt==value);

  } // end isSort

  public boolean isSort(int value)
  {
    return (sort_opt==value);

  } // end isSort

  public Iterator getTopicIterator()
  {
    return topic_list.iterator();

  } // end getTopicIterator

} // end class TopicListing
