/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.awt.Dimension;
import javax.servlet.ServletRequest;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.core.VeniceEngine;
import com.silverwrist.venice.core.UserProfile;

public class UserProfileData implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.UserProfileData";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private VeniceEngine engine;
  private UserProfile prof;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public UserProfileData(VeniceEngine engine, UserProfile prof)
  {
    this.engine = engine;
    this.prof = prof;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static UserProfileData retrieve(ServletRequest request)
  {
    return (UserProfileData)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    return "User Profile - " + prof.getUserName();

  } // end getPageTitle

  public String getPageQID()
  {
    return "user/" + prof.getUserName();

  } // end getPageQID

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "userprofile.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public UserProfile getUserProfile()
  {
    return prof;

  } // end getUserProfile

  public String getAddressLastLine()
  {
    String tmp_c = prof.getLocality();
    String tmp_s = prof.getRegion();
    StringBuffer buf = new StringBuffer();
    if (!(StringUtil.isStringEmpty(tmp_c)) && !(StringUtil.isStringEmpty(tmp_s)))
      buf.append(tmp_c).append(", ").append(tmp_s);
    else if (!(StringUtil.isStringEmpty(tmp_c)))
      buf.append(tmp_c);
    else if (!(StringUtil.isStringEmpty(tmp_s)))
      buf.append(tmp_s);
    tmp_s = prof.getPostalCode();
    if (!(StringUtil.isStringEmpty(tmp_s)))
      buf.append(' ').append(tmp_s);
    return buf.toString();

  } // end getAddressLastLine

  public String getFullName()
  {
    StringBuffer buf = new StringBuffer(prof.getGivenName());
    String tmp = prof.getNamePrefix();
    if (!(StringUtil.isStringEmpty(tmp)))
    { // insert prefix at beginning
      buf.insert(0,' ');
      buf.insert(0,tmp);

    } // end if
    if (prof.getMiddleInitial()!=' ')
      buf.append(' ').append(prof.getMiddleInitial()).append('.');
    buf.append(' ').append(prof.getFamilyName());
    tmp = prof.getNameSuffix();
    if (!(StringUtil.isStringEmpty(tmp)))
      buf.append(' ').append(tmp);
    return buf.toString();

  } // end getFullName

  public String getPhotoTag(RenderData rdat)
  {
    Dimension dim = engine.getUserPhotoSize();
    StringBuffer buf = new StringBuffer("<IMG SRC=\"");
    String tmp = prof.getPhotoURL();
    if (StringUtil.isStringEmpty(tmp))
      tmp = rdat.getPhotoNotAvailURL();
    buf.append(tmp).append("\" ALT=\"\" ALIGN=LEFT WIDTH=").append(dim.width).append(" HEIGHT=");
    buf.append(dim.height).append(" BORDER=0>");
    return buf.toString();

  } // end getPhotoTag

} // end class UserProfileData
